package com.example.educheckin.config;

import com.auth0.jwt.JWT;
import com.auth0.jwt.JWTVerifier;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.exceptions.JWTVerificationException;
import com.example.educheckin.annotation.Scope;
import com.example.educheckin.annotation.UserToken;
import com.example.educheckin.controller.UserController;
import com.example.educheckin.entity.User;
import com.example.educheckin.service.UserService;
import com.example.educheckin.service.UserServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.stereotype.Component;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.PrintWriter;
import java.lang.reflect.Method;

public class AuthenticationInterceptor implements HandlerInterceptor {
    @Autowired
    UserService userServiceImpl;

    @Override
    public boolean preHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse,
                             Object object) throws Exception {
        System.out.println(httpServletRequest.getRequestURI());

        try {
            String token1 = httpServletRequest.getHeader("token");
            String token2 = httpServletRequest.getHeader("Authorization");
            String token = token2 == null ? token1 : token2.split(" ")[1];
            String paramEmail = httpServletRequest.getParameter("email");


            if (!(object instanceof HandlerMethod handlerMethod)) {
                return true;
            }
            Method method = handlerMethod.getMethod();

            Verify(method, token, paramEmail);

        } catch (Exception e) {
            httpServletResponse.setStatus(401);
            httpServletResponse.setContentType("text/plain; charset=utf-8");
            PrintWriter out = httpServletResponse.getWriter();
            out.write("Permission denied.");
            out.close();
            return false;
        }
        return true;
    }

    @Override
    public void postHandle(HttpServletRequest httpServletRequest,
                           HttpServletResponse httpServletResponse,
                           Object o, ModelAndView modelAndView) throws Exception {

    }

    @Override
    public void afterCompletion(HttpServletRequest httpServletRequest,
                                HttpServletResponse httpServletResponse,
                                Object o, Exception e) throws Exception {

    }

    private void Verify(Method method, String token, String paramEmail) throws Exception {
        // Verify token
        if (method.isAnnotationPresent(UserToken.class)) {
            UserToken userToken = method.getAnnotation(UserToken.class);
            if (userToken.value() == -1) {
                return;
            }
            String userEmail = JWT.decode(token).getAudience().get(0);
            User user = userServiceImpl.getUser(userEmail);

            if (user == null || Integer.parseInt(user.getAdmin()) < userToken.value()) {
                throw new Exception("Permission denied.");
            }

            JWTVerifier jwtVerifier = JWT.require(Algorithm.HMAC256(user.getPassword())).build();
            jwtVerifier.verify(token);
        }
        // Verify param
        if (paramEmail != null && method.isAnnotationPresent(Scope.class)) {
            int scope = method.getAnnotation(Scope.class).value();
            switch (scope) {
                case 0 -> {
                    if (!paramEmail.equals(JWT.decode(token).getAudience().get(0))) {
                        throw new Exception("Permission denied.");
                    }
                }
                case 1 -> {
                    String currentEmail = JWT.decode(token).getAudience().get(0);
                    if (!paramEmail.equals(currentEmail) && Integer.parseInt(userServiceImpl.getUser(currentEmail).getAdmin()) < 1) {
                        throw new Exception("Permission denied.");
                    }
                }
                case 2 -> {
                    String currentEmail = JWT.decode(token).getAudience().get(0);
                    if (!paramEmail.equals(currentEmail) && Integer.parseInt(userServiceImpl.getUser(currentEmail).getAdmin()) < 2) {
                        throw new Exception("Permission denied.");
                    }
                }
                default -> throw new Exception("Permission denied.");
            }
        }
    }

}