package com.example.educheckin.controller;

import com.example.educheckin.annotation.UserToken;
import com.example.educheckin.entity.CheckInItem;
import com.example.educheckin.service.CheckService;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.sql.Time;
import java.sql.Timestamp;
import java.util.List;

@ApiResponses(
        {
                @ApiResponse(responseCode = "200", description = "OK"),
                @ApiResponse(responseCode = "400", description = "Client Error", content = @Content()),
                @ApiResponse(responseCode = "401", description = "Unauthorized", content = @Content()),
                @ApiResponse(responseCode = "500", description = "Server Error", content = @Content()),
        })
@RestController
@Tag(name = "打卡")
public class CheckController
{
    @Autowired
    private CheckService checkService;

    @Operation(summary = "增改一条打卡记录",description = "Access 0")
    @ApiResponses(
            {
                    @ApiResponse(responseCode = "200", description = "成功增加了一条打卡记录"),
                    @ApiResponse(responseCode = "280", description = "成功修改了一条当日打卡记录"),
                    @ApiResponse(responseCode = "500", description = "Error"),
            })
    @PostMapping("/modCheck")
    @UserToken()
    public ResponseEntity<Void> AddCheck(@Parameter(description = "邮箱") @RequestParam String email,
                                         @Parameter(description = "当前时间(yyyy-MM-dd HH:mm:ss)") @RequestParam String time,
                                         @Parameter(description = "备课,0为没有勾选,1为勾选") @RequestParam int prepare,
                                         @Parameter(description = "上课,0为没有勾选,1为勾选") @RequestParam int goClass,
                                         @Parameter(description = "听课,0为没有勾选,1为勾选") @RequestParam
                                         int listenClass,
                                         @Parameter(description = "批改作业,0为没有勾选,1为勾选") @RequestParam
                                             int markHomework,
                                         @Parameter(description = "批改试卷,0为没有勾选,1为勾选") @RequestParam
                                         int markPaper,
                                         @Parameter(description = "其他") @RequestParam(required = false) String other)
    {
        CheckInItem checkInItem = new CheckInItem(email, Timestamp.valueOf(time), prepare, goClass, listenClass, markHomework, markPaper, other);
        String ans = checkService.goCheck(checkInItem);
        return switch (ans)
                {
                    case "success" -> ResponseEntity.status(200).body(null);
                    case "update" -> ResponseEntity.status(280).body(null);
                    default -> ResponseEntity.status(500).body(null);
                };
    }

    @Operation(summary = "查询一个人某天的打卡记录",description = "Access 0")
    @ApiResponses(@ApiResponse(responseCode = "280", description = "未找到当天的打卡记录", content = @Content()))
    @GetMapping("/getCheck")
    @UserToken()
    public ResponseEntity<CheckInItem> GetCheck(@Parameter(description = "邮箱") @RequestParam String email,
                                                @Parameter(description = "查询日期(yyyy-MM-dd)") @RequestParam
                                                String date)
    {
        Timestamp time = Timestamp.valueOf(date + " 00:00:00");
        CheckInItem checkInItem = checkService.getCheck(email, time);
        if (checkInItem == null)
        {
            return ResponseEntity.status(280).body(null);
        }
        return ResponseEntity.status(200).body(checkInItem);
    }

    @UserToken()
    @Operation(summary = "查询一个人所有打卡记录",description = "Access 0")
    @ApiResponses(@ApiResponse(responseCode = "280", description = "未找到该用户的打卡记录"))
    @GetMapping("/getAllCheck")
    public ResponseEntity<List<CheckInItem>> GetAllCheck(@Parameter(description = "邮箱") @RequestParam String email)
    {
        List<CheckInItem> checkList = checkService.getCheckList(email);
        if (checkList == null)
        {
            return ResponseEntity.status(280).body(null);
        }
        return ResponseEntity.status(200).body(checkList);
    }

    @UserToken()
    @Operation(summary = "查询一个人前一天之前连续打卡天数",description = "Access 0")
    @GetMapping("/getCheckConstant")
    public ResponseEntity<Integer> GetCheckConstant(@Parameter(description = "邮箱") @RequestParam String email,
                                                    @Parameter(description = "查询日期(yyyy-MM-dd)") @RequestParam
                                                    String date)
    {
        Timestamp time = Timestamp.valueOf(date + " 00:00:00");
        int constant = checkService.constantCheckNumber(email, time);
        return ResponseEntity.status(200).body(constant);
    }

    @UserToken()
    @Operation(summary = "查询一个人两个时间(以天数计)的打卡状态",description = """
            Access 0,其中将会返回
            a list of data , list[0] is total days, list[1] is total check days, list[2] is prepare days,
            list[3] is go class days, list[4] is listen class days, list[5] is mark homework days, list[6] is mark paper days.""")
    @GetMapping("/getCheckStatus")
    public ResponseEntity<List<Integer>> GetCheckStatus(@Parameter(description = "邮箱") @RequestParam String email,
                                                        @Parameter(description = "查询日期(yyyy-MM-dd)") @RequestParam
                                                        String startDay,
                                                        @Parameter(description = "查询日期(yyyy-MM-dd)") @RequestParam
                                                        String endDay)
    {
        Timestamp start = Timestamp.valueOf(startDay + " 00:00:00");
        Timestamp end = Timestamp.valueOf(endDay + " 00:00:00");
        List<Integer> status = checkService.calculateRateBetweenTime(email, start, end);
        return ResponseEntity.status(200).body(status);
    }


}
