package com.example.educheckin.controller;

import com.example.educheckin.annotation.UserToken;
import com.example.educheckin.service.FileService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.Resource;
import org.springframework.core.io.UrlResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Path;
import java.nio.file.Paths;

@ApiResponses({
        @ApiResponse(responseCode = "200", description = "请求成功", content = {@Content(schema = @Schema())}),
        @ApiResponse(responseCode = "400", description = "客户端错误", content = {@Content(schema = @Schema())}),
        @ApiResponse(responseCode = "401", description = "权限不足", content = {@Content(schema = @Schema())}),
        @ApiResponse(responseCode = "500", description = "服务器错误", content = {@Content(schema = @Schema())})})
@Tag(name = "文件上传")
@RestController
public class FileController
{

    @Autowired
    FileService fileService;

    @Operation(
            summary = "上传/更新评价表",
            description = "Access 0，对于已经存有数据的用户，将直接覆盖对应的表，对于未存有数据的用户，将会新建一个条目")
    @ApiResponses(
            {
                    @ApiResponse(responseCode = "200", description = "成功创建了一个条目"),
                    @ApiResponse(responseCode = "500", description = "Error"),
            })
    @PostMapping(path = "/fileUpload", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    @UserToken()
    public ResponseEntity<String> fileUpload(@Parameter(description = "邮箱") @RequestParam String email,
                                             @Parameter(description = "自评表") @RequestPart(required = false)
                                             MultipartFile selfAssessmentFormBin,
                                             @Parameter(description = "互评表") @RequestPart(required = false)
                                             MultipartFile mutualEvaluationFormBin,
                                             @Parameter(description = "学生评价表") @RequestPart(required = false)
                                             MultipartFile studentEvaluationForm)
    {
        return switch (fileService.fileUpload(email, selfAssessmentFormBin, mutualEvaluationFormBin,
                                              studentEvaluationForm))
                {
                    case 0 -> ResponseEntity.ok("未能上传或者更新文件");
                    case 1 -> ResponseEntity.ok("成功上传或者更新了1个文件");
                    case 2 -> ResponseEntity.ok("成功上传或者更新了2个文件");
                    case 3 -> ResponseEntity.ok("成功上传或者更新了3个文件");
                    default -> ResponseEntity.status(500).body("Error");
                };
    }

    @Operation(
            summary = "获取自评表",
            description = "Access 0，返回自评表的二进制文件")
    @ApiResponses(
            {
                    @ApiResponse(responseCode = "200", description = "成功获取了自评表"),
                    @ApiResponse(responseCode = "280", description = "尚未上传这个文件"),
                    @ApiResponse(responseCode = "500", description = "Error"),
            })
    @GetMapping(path = "/getSelfAssessmentForm", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @UserToken()
    public ResponseEntity<byte[]> getSelfAssessmentForm(
            @Parameter(description = "邮箱") @RequestParam String email) throws IOException
    {
        if (fileService.getSelfAssessmentFormName(email) == null)
            return ResponseEntity.status(280).body(null);
        else
        {
            InputStream os = fileService.getSelfAssessmentForm(email);
            String fileName = fileService.getSelfAssessmentFormName(email);
            return ResponseEntity.ok()
                    .header("Content-Disposition", "attachment; filename=\"" + fileName+ "\"")
                    .body(os.readAllBytes());
        }
    }

    @Operation(
            summary = "获取互评表",
            description = "Access 0，返回互评表的二进制文件")
    @ApiResponses(
            {
                    @ApiResponse(responseCode = "200", description = "成功获取了互评表"),
                    @ApiResponse(responseCode = "280", description = "尚未上传这个文件"),
                    @ApiResponse(responseCode = "500", description = "Error"),
            })
    @GetMapping(path = "/getMutualEvaluationForm", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @UserToken()
    public ResponseEntity<byte[]> getMutualEvaluationForm(
            @Parameter(description = "邮箱") @RequestParam String email) throws IOException
    {
        if (fileService.getMutualEvaluationFormName(email) == null)
            return ResponseEntity.status(280).body(null);
        else
        {
            InputStream os = fileService.getMutualEvaluationForm(email);
            String fileName = fileService.getMutualEvaluationFormName(email);
            return ResponseEntity.ok()
                    .header("Content-Disposition", "attachment; filename=\"" + fileName+ "\"")
                    .body(os.readAllBytes());
        }
    }

    @Operation(
            summary = "获取学生评价表",
            description = "Access 0，返回学生评价表的二进制文件")
    @ApiResponses(
            {
                    @ApiResponse(responseCode = "200", description = "成功获取了学生评价表"),
                    @ApiResponse(responseCode = "280", description = "尚未上传这个文件"),
                    @ApiResponse(responseCode = "500", description = "Error"),
            })
    @GetMapping(path = "/getStudentEvaluationForm", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @UserToken()
    public ResponseEntity<byte[]> getStudentEvaluationForm(
            @Parameter(description = "邮箱") @RequestParam String email) throws IOException
    {
        if (fileService.getStudentEvaluationFormName(email) == null)
            return ResponseEntity.status(280).body(null);
        else
        {
            InputStream os = fileService.getStudentEvaluationForm(email);
            String fileName = fileService.getStudentEvaluationFormName(email);
            return ResponseEntity.ok()
                    .header("Content-Disposition", "attachment; filename=\"" + fileName+ "\"")
                    .body(os.readAllBytes());
        }
    }

    @Operation(summary = "获得评价表模板", description = "无需登录即可访问，当前有EvaluationFormTemplate.docx")
    @ApiResponse(responseCode = "200", description = "成功获取了评价表模板", content = @Content(schema = @Schema(implementation = Resource.class)))
    @ApiResponse(responseCode = "404", description = "文件不存在", content = {@Content(schema = @Schema())})
    @GetMapping(path = "/getFiles/{fileName}", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    public ResponseEntity<Resource> serveFile(@PathVariable String fileName) throws IOException {
        String fileBasePath = "/home/ubuntu/jar/";
        Path filePath = Paths.get(fileBasePath).resolve(fileName);
        System.out.println(filePath+" "+filePath.toUri());
        Resource resource = new UrlResource(filePath.toUri());

        if (resource.exists() && resource.isReadable()) {
            return ResponseEntity.ok().header(HttpHeaders.CONTENT_DISPOSITION,
                    "attachment; filename=\"" + resource.getFilename() + "\"").body(resource);
        } else {
            return ResponseEntity.notFound().build();
        }
    }



}

