package com.example.educheckin.controller;

import com.example.educheckin.annotation.UserToken;
import com.example.educheckin.entity.InviteCode;
import com.example.educheckin.service.InviteCodeServiceImpl;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.ExampleObject;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.swing.*;
import java.util.List;

@RestController
@Tag(name = "邀请码")
@ApiResponses({
        @ApiResponse(responseCode = "200", description = "请求成功", content = {@Content(schema = @Schema())}),
        @ApiResponse(responseCode = "400", description = "客户端错误", content = {@Content(schema = @Schema())}),
        @ApiResponse(responseCode = "401", description = "权限不足", content = {@Content(schema = @Schema())}),
        @ApiResponse(responseCode = "500", description = "服务器错误", content = {@Content(schema = @Schema())})})
public class InviteCodeController {

    @Autowired
    private InviteCodeServiceImpl inviteCodeServiceImpl;


    @Operation(summary = "增加邀请码", description = "仅限管理员访问")
    @PutMapping("/addInviteCode")
    @ApiResponse(responseCode = "280", description = "邀请码重复", content = {@Content(schema = @Schema())})
    @UserToken(2)
    public ResponseEntity<Void> addInviteCode(@Parameter(description = "邀请码字段") @RequestParam String code,
                                              @Parameter(
                                                      description = "邀请码管理员模式,0为用户,1为管理者,2为超级管理员")
                                              @RequestParam String admin,
                                              @Parameter(description = "邀请码状态,0为未使用,1为已使用") @RequestParam
                                              String used,
                                              @Parameter(
                                                      description = "若为管理者为所管理组名,若非管理者为其所在的组号",
                                                      required = false)
                                              @RequestParam List<String> group) {
        InviteCode inviteCode = new InviteCode(code, admin, used, group);
        String ans = inviteCodeServiceImpl.addInviteCode(inviteCode);
        return switch (ans) {
            case "code exist" -> ResponseEntity.status(280).body(null);
            case "success" -> ResponseEntity.status(200).body(null);
            default -> ResponseEntity.status(500).body(null);
        };
    }

    @Operation(summary = "修改邀请码",description = "仅限管理员访问")
    @PostMapping("/updateInviteCode")
    @UserToken()
    public ResponseEntity<Void> updateInviteCode(@Parameter(description = "邀请码字段") @RequestParam String code,
                                                 @Parameter(
                                                         description = "邀请码管理员模式,0为用户,1为管理者,2为超级管理员")
                                                 @RequestParam String admin,
                                                 @Parameter(description = "邀请码状态,0为未使用,1为已使用")
                                                 @RequestParam
                                                 String used,
                                                 @Parameter(
                                                         description = "若为管理者为所管理组名,若非管理者为其所在的组号",
                                                         required = false)
                                                 @RequestParam List<String> group) {
        if (inviteCodeServiceImpl.updateInviteCode(new InviteCode(code, admin, used, group))) {
            return ResponseEntity.status(200).body(null);
        } else {
            return ResponseEntity.status(500).body(null);
        }
    }

    @Operation(summary = "展示某个邀请码",description = "Access 0")
    @GetMapping("/showInviteCode")
    @ApiResponse(responseCode = "200", description = "请求成功", content = {@Content(schema = @Schema(implementation = InviteCode.class))})
    @ApiResponse(responseCode = "280", description = "邀请码不存在", content = {@Content(schema = @Schema())})
    @UserToken()
    public ResponseEntity<InviteCode> getInviteCode(@Parameter(description = "邀请码字段") @RequestParam String code) {
        InviteCode inviteCode = inviteCodeServiceImpl.getInviteCode(code);
        if (inviteCode == null) {
            return ResponseEntity.status(280).body(null);
        } else {
            return ResponseEntity.status(200).body(inviteCode);
        }
    }

    @Operation(summary = "生成一组邀请码，其中第一个为老师使用的邀请码，其余为学生使用的邀请码",description = "Access 2")
    @PutMapping("/summonInviteCode")
    @ApiResponse(responseCode = "200", description = "请求成功", content = {@Content(schema = @Schema(implementation = String.class))})
    @UserToken(2)
    public ResponseEntity<String> summonInviteCode() {
        String ans = "Teacher:";
        for(String s : inviteCodeServiceImpl.summonInviteCode()){
            ans += s + "\n";
        }

        return ResponseEntity.status(200).body(ans);

    }
}
