package com.example.educheckin.controller;

import com.example.educheckin.annotation.Scope;
import com.example.educheckin.annotation.UserToken;
import com.example.educheckin.service.ScoreService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@Tag(name = "评价得分")
@ApiResponses({
        @ApiResponse(responseCode = "200", description = "请求成功", content = {@Content(schema = @Schema())}),
        @ApiResponse(responseCode = "400", description = "客户端错误", content = {@Content(schema = @Schema())}),
        @ApiResponse(responseCode = "401", description = "权限不足", content = {@Content(schema = @Schema())}),
        @ApiResponse(responseCode = "500", description = "服务器错误", content = {@Content(schema = @Schema())})})
public class ScoreController {
    @Autowired
    private ScoreService scoreService;

    @Operation(summary = "获取自评分数", description = "获取自评分数")
    @GetMapping("/getSelfScore")
    @Scope(1)
    @UserToken()
    public List<Integer> getSelfScore(String email) {
        return scoreService.getSelfScore(email);
    }

    @Operation(summary = "获取组评分数", description = "获取组评分数")
    @GetMapping("/getGroupScore")
    @Scope(1)
    @UserToken()
    public List<Integer> getGroupScore(String email) {
        return scoreService.getGroupScore(email);
    }

    @Operation(summary = "获取学生评分数", description = "获取学生评分数")
    @GetMapping("/getStudentScore")
    @Scope(1)
    @UserToken()
    public List<Integer> getStudentScore(String email) {
        return scoreService.getStudentScore(email);
    }

    @Operation(summary = "获取教师评分数", description = "获取教师评分数")
    @GetMapping("/getTeacherScore")
    @Scope(1)
    @UserToken()
    public List<Integer> getTeacherScore(String email) {
        return scoreService.getTeacherScore(email);
    }

    @Operation(summary = "进行自评", description = "插入自评得分")
    @PostMapping("/insertSelfScore")
    @Scope()
    @UserToken()
    public ResponseEntity<Void> insertSelfScore(String email, String scoreString) {
        if (scoreService.insertSelfScore(email, scoreString)) {
            return ResponseEntity.status(200).body(null);
        } else {
            return ResponseEntity.status(500).body(null);
        }
    }

    @Operation(summary = "进行组评", description = "插入组评得分")
    @PostMapping("/insertGroupScore")
    @UserToken()
    public ResponseEntity<Void> insertGroupScore(String email, String scoreString) {
        if (scoreService.insertGroupScore(email, scoreString)) {
            return ResponseEntity.status(200).body(null);
        } else {
            return ResponseEntity.status(500).body(null);
        }
    }

    @Operation(summary = "进行学生评", description = "插入学生评得分")
    @PostMapping("/insertStudentScore")
    @UserToken()
    public ResponseEntity<Void> insertStudentScore(String email, String scoreString) {
        if (scoreService.insertStudentScore(email, scoreString)) {
            return ResponseEntity.status(200).body(null);
        } else {
            return ResponseEntity.status(500).body(null);
        }
    }

    @Operation(summary = "进行教师评", description = "插入教师评得分")
    @PostMapping("/insertTeacherScore")
    @UserToken(1)
    public ResponseEntity<Void> insertTeacherScore(String email, String scoreString) {
        if (scoreService.insertTeacherScore(email, scoreString)) {
            return ResponseEntity.status(200).body(null);
        } else {
            return ResponseEntity.status(500).body(null);
        }
    }

    @Operation(summary = "判断是否重复提交", description = "判断是否重复提交")
    @PostMapping("/isRepeat")
    @UserToken(-1)
    @ApiResponse(responseCode = "200", description = "未重复", content = {@Content(schema = @Schema())})
    @ApiResponse(responseCode = "280", description = "重复提交", content = {@Content(schema = @Schema())})
    public ResponseEntity<Boolean> isRepeat(String str) {
        if (scoreService.isRepeat(str)) {
            return ResponseEntity.status(200).body(true);
        } else {
            return ResponseEntity.status(280).body(false);
        }
    }


}
