package com.example.educheckin.dataAccessObject;

import com.example.educheckin.entity.CheckInItem;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import java.sql.Timestamp;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.util.List;

@Repository
public class CheckDAOlmpl implements CheckDAO
{
    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Override
    public boolean addCheckDAO(CheckInItem item)
    {
        String sql = "INSERT INTO `check` (`email`, time, prepare, `go_class`, `listen_class`, `mark_homework`, `mark_paper`, `other`) VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
        return jdbcTemplate.update(sql, item.getEmail(), item.getTime(),
                                   item.getPrepare(), item.getGo_class(), item.getListen_class(),
                                   item.getMark_homework(), item.getMark_paper(), item.getOther()) >= 1;
    }

    @Override
    public boolean reviseCheckDAO(CheckInItem item, int id)
    {
        String sql = "UPDATE `check`  SET email=?, time=?, prepare=?, go_class=?, listen_class=?, mark_homework=?, mark_paper=?, other=? WHERE id=?";
        return jdbcTemplate.update(sql, item.getEmail(), item.getTime(),
                                   item.getPrepare(), item.getGo_class(), item.getListen_class(),
                                   item.getMark_homework(), item.getMark_paper(), item.getOther(), id ) >= 1;
    }

    @Override
    public int getCheckIdDAO(String email, Timestamp time)
    {
        ZonedDateTime zdt = time.toInstant().atZone(ZoneId.systemDefault()); // 转换为ZonedDateTime
        ZonedDateTime zdtStart = zdt.toLocalDate().atStartOfDay(zdt.getZone()); // 获取当天的第一秒
        ZonedDateTime zdtEnd = zdtStart.plusDays(1).minusNanos(1); // 获取当天的最后一秒
        Timestamp start = Timestamp.from(zdtStart.toInstant()); // 转换回Timestamp
        Timestamp end = Timestamp.from(zdtEnd.toInstant()); // 转换回Timestamp
        String sql = "SELECT id FROM `check`  WHERE email=? AND time BETWEEN ? AND ?";
        try
        {
            return jdbcTemplate.queryForObject(sql, Integer.class, email, start, end);
        }
        catch (Exception e)
        {
            return -1;
        }
    }

    @Override
    public CheckInItem getCheckDAO(int id)
    {
        String sql = "SELECT * FROM `check`  WHERE id=?";
        return jdbcTemplate.query(sql, (rs) ->
        {
            if (rs.next())
            {
                return new CheckInItem(
                        rs.getString("email"),
                        rs.getTimestamp("time"),
                        rs.getInt("prepare"),
                        rs.getInt("go_class"),
                        rs.getInt("listen_class"),
                        rs.getInt("mark_homework"),
                        rs.getInt("mark_paper"),
                        rs.getString("other")
                );
            }
            else
            {
                return null;
            }
        }, id);
    }

    @Override
    public List<CheckInItem> getCheckListDAO(String email)
    {
        String sql = "SELECT * FROM `check` WHERE email=?";
        return jdbcTemplate.query(sql, (rs, rowNum) ->
                new CheckInItem(
                        rs.getString("email"),
                        rs.getTimestamp("time"),
                        rs.getInt("prepare"),
                        rs.getInt("go_class"),
                        rs.getInt("listen_class"),
                        rs.getInt("mark_homework"),
                        rs.getInt("mark_paper"),
                        rs.getString("other")
                ), email);
    }

}
