package com.example.educheckin.dataAccessObject;

import java.io.InputStream;
import java.io.OutputStream;

public interface FileDAO
{
    /**
     * Upload/Update the self-assessment form
     * @param email the email of the user
     * @param selfAssessmentFormName the name of the self-assessment form
     * @param selfAssessmentFormBin the self-assessment form
     * @return if success return 1, else return 0
     */
     int selfAssessmentUpload(String email, String selfAssessmentFormName,InputStream selfAssessmentFormBin);

    /**
    * Upload/Update the mutual-evaluation form
    * @param email the email of the user
    * @param mutualEvaluationFormName the name of the mutual-evaluation form
    * @param mutualEvaluationFormBin the mutual-evaluation form
    * @return if success return 1, else return 0
    */
    int mutualEvaluationUpload(String email, String mutualEvaluationFormName,InputStream mutualEvaluationFormBin);

    /**
     * Upload/Update the student-evaluation form
     * @param email the email of the user
     * @param studentEvaluationFormName the name of the student-evaluation form
     * @param studentEvaluationFormBin the student-evaluation form
     */
    int studentEvaluationUpload(String email, String studentEvaluationFormName,InputStream studentEvaluationFormBin);

    /**
     * Check if email in database
     * @param email the email of the user
     * @return if success return 1, else return 0
     */
    int checkEmail(String email);

    /**
     * Init the file row in database
     * @param email the email of the user
     * @return if success return 1, else return 0
     */
    int initFile(String email);

    /**
     * Get the self-assessment form
     * @param email the email of the user
     * @return the self-assessment form
     */
    InputStream getSelfAssessmentForm(String email);

    /**
     * Get the mutual-evaluation form
     * @param email the email of the user
     * @return the mutual-evaluation form
     */
    InputStream getMutualEvaluationForm(String email);

    /**
     * Get the student-evaluation form
     * @param email the email of the user
     * @return the student-evaluation form
     */
    InputStream getStudentEvaluationForm(String email);

    /**
     * Get the name of the self-assessment form
     * @param email the email of the user
     * @return the name of the self-assessment form
     */
    String getSelfAssessmentFormName(String email);

    /**
     * Get the name of the mutual-evaluation form
     * @param email the email of the user
     * @return the name of the mutual-evaluation form
     */
    String getMutualEvaluationFormName(String email);

    /**
     * Get the name of the student-evaluation form
     * @param email the email of the user
     * @return the name of the student-evaluation form
     */
    String getStudentEvaluationFormName(String email);
}
