package com.example.educheckin.dataAccessObject;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.List;

@Repository
public class FileDAOImpl implements FileDAO
{
    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Override
    public int selfAssessmentUpload(String email, String selfAssessmentFormName, InputStream selfAssessmentFormBin)
    {
        return jdbcTemplate.update(
                "UPDATE file SET self_assessment_form_name = ?, self_assessment_form_bin = ? WHERE email = ?" ,
                selfAssessmentFormName, selfAssessmentFormBin, email);
    }

    @Override
    public int mutualEvaluationUpload(String email, String mutualEvaluationFormName,
                                      InputStream mutualEvaluationFormBin)
    {
        return jdbcTemplate.update(
                "UPDATE file SET mutual_evaluation_form_name = ?, mutual_evaluation_form_bin = ? WHERE email = ?",
                mutualEvaluationFormName, mutualEvaluationFormBin, email);
    }

    @Override
    public int studentEvaluationUpload(String email, String studentEvaluationFormName,
                                       InputStream studentEvaluationFormBin)
    {
        return jdbcTemplate.update(
                "UPDATE file SET student_evaluation_form_name = ?, student_evaluation_form_bin = ? WHERE email = ?",
                 studentEvaluationFormName, studentEvaluationFormBin, email);
    }

    @Override
    public int checkEmail(String email)
    {
        return jdbcTemplate.queryForObject("SELECT COUNT(*) FROM file WHERE email = ?", Integer.class, email);
    }

    @Override
    public int initFile(String email)
    {
        return jdbcTemplate.update("INSERT INTO file (email) VALUES (?)", email);
    }

    @Override
    public InputStream getSelfAssessmentForm(String email)
    {
        List<InputStream> results = jdbcTemplate.query("SELECT self_assessment_form_bin FROM file WHERE email = ?",
                                                       new Object[]{email},
                                                       (rs, rowNum) -> rs.getBinaryStream("self_assessment_form_bin"));

        if (results.isEmpty())
        {
            return null;
        }
        else
        {
            return results.get(0);
        }
    }

    @Override
    public InputStream getMutualEvaluationForm(String email)
    {
        List<InputStream> results = jdbcTemplate.query("SELECT mutual_evaluation_form_bin FROM file WHERE email = ?",
                                                       new Object[]{email}, (rs, rowNum) -> rs.getBinaryStream(
                        "mutual_evaluation_form_bin"));

        if (results.isEmpty())
        {
            return null;
        }
        else
        {
            return results.get(0);
        }
    }

    @Override
    public InputStream getStudentEvaluationForm(String email)
    {
        List<InputStream> results = jdbcTemplate.query("SELECT student_evaluation_form_bin FROM file WHERE email = ?",
                                                       new Object[]{email}, (rs, rowNum) -> rs.getBinaryStream(
                        "student_evaluation_form_bin"));

        if (results.isEmpty())
        {
            return null;
        }
        else
        {
            return results.get(0);
        }
    }

    @Override
    public String getSelfAssessmentFormName(String email)
    {
        List<String> results = jdbcTemplate.query("SELECT self_assessment_form_name FROM file WHERE email = ?",
                                                  new Object[]{email},
                                                  (rs, rowNum) -> rs.getString("self_assessment_form_name"));

        if (results.isEmpty())
        {
            return null;
        }
        else
        {
            return results.get(0);
        }
    }

    @Override
    public String getMutualEvaluationFormName(String email)
    {
        List<String> results = jdbcTemplate.query("SELECT mutual_evaluation_form_name FROM file WHERE email = ?",
                                                  new Object[]{email},
                                                  (rs, rowNum) -> rs.getString("mutual_evaluation_form_name"));

        if (results.isEmpty())
        {
            return null;
        }
        else
        {
            return results.get(0);
        }
    }

    @Override
    public String getStudentEvaluationFormName(String email)
    {
        List<String> results = jdbcTemplate.query("SELECT student_evaluation_form_name FROM file WHERE email = ?",
                                                  new Object[]{email},
                                                  (rs, rowNum) -> rs.getString("student_evaluation_form_name"));

        if (results.isEmpty())
        {
            return null;
        }
        else
        {
            return results.get(0);
        }
    }
}