package com.example.educheckin.dataAccessObject;

import com.example.educheckin.entity.InviteCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.Objects;

@Repository
public class InviteCodeDAOImpl implements InviteCodeDAO
{
    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Override
    public boolean addInviteCode(InviteCode inviteCode)
    {
        String sql = "INSERT INTO invite_code (code, admin, used, `group`) VALUES (?, ?, ? , ?)";
        return jdbcTemplate.update(sql, inviteCode.getCode(), inviteCode.getAdmin(), inviteCode.getUsed(),
                            inviteCode.GroupString()) >= 1;
    }


    @Override
    public boolean setCodeUsed(String code)
    {
        String sql = "UPDATE invite_code SET used=? WHERE code=?";
        return jdbcTemplate.update(sql, "1", code) >= 1;
    }

    @Override
    public boolean getCodeAdmin(String code)
    {
        String sql = "SELECT admin FROM invite_code WHERE code=?";
        return Objects.equals("1", jdbcTemplate.queryForObject(sql, String.class, code));
    }


    @Override
    public boolean updateInviteCode(InviteCode inviteCode)
    {
        String sql = "UPDATE invite_code SET admin=?, used=? ,`group` = ?WHERE code=?";
        return jdbcTemplate.update(sql, inviteCode.getAdmin(), inviteCode.getUsed(), inviteCode.GroupString(),
                            inviteCode.getCode()) >= 1;

    }

    @Override
    public InviteCode getInviteCode(String code)
    {
        String sql = "SELECT * FROM invite_code WHERE code=?";
        return jdbcTemplate.query(sql, (rs) -> {
            if (rs.next()) {
                return new InviteCode(
                        rs.getString("code"),
                        rs.getString("admin"),
                        rs.getString("used"),
                        rs.getString("group")
                );
            } else {
                return null;
            }
        }, code);
    }


    @Override
    public boolean deleteInviteCode(String code)
    {
        if (Objects.equals(getInviteCode(code).getUsed(), "1"))
            return false;
        String sql = "DELETE FROM invite_code WHERE code=?";
        jdbcTemplate.update(sql, code);
        return true;
    }
}
