package com.example.educheckin.dataAccessObject;

public interface ScoreDAO {
    /**
     * Get self score by email
     *
     * @param email the email of the user
     * @return the score of the user
     */
    String getSelfScoreDAO(String email);

    /**
     * Get group score by email
     *
     * @param email the email of the user
     * @return the score of the group
     */
    String getGroupScoreDAO(String email);

    /**
     * Get student score by email
     *
     * @param email the email of the user
     * @return the score of the student
     */
    String getStudentScoreDAO(String email);

    /**
     * Get teacher score by email
     *
     * @param email the email of the user
     * @return the score of the user
     */
    String getTeacherScoreDAO(String email);

    /**
     * Insert self score string into database(1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F)
     *
     * @param email       the email of the user
     * @param scoreString the score string of the user
     * @return true if the score is inserted, false if not
     */
    boolean insertSelfScoreDAO(String email, String scoreString);

    /**
     * Insert group score string into database(1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F),
     * here, if already have a group score, then append the new score to the end of the string, with space in between
     *
     * @param email       the email of the user
     * @param scoreString the score string of the user
     * @return true if the score is inserted, false if not
     */
    boolean insertGroupScoreDAO(String email, String scoreString);

    /**
     * Insert student score string into database(1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F),
     * here, if already have a student score, then append the new score to the end of the string, with space in between
     *
     * @param email       the email of the user
     * @param scoreString the score string of the user
     * @return true if the score is inserted, false if not
     */
    boolean insertStudentScoreDAO(String email, String scoreString);

    /**
     * Insert teacher score string into database(1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F),
     * here, if already have a teacher score, then append the new score to the end of the string, with space in between
     *
     * @param email       the email of the user
     * @param scoreString the score string of the user
     * @return true if the score is inserted, false if not
     */
    boolean insertTeacherScoreDAO(String email, String scoreString);

    /**
     * Add an empty line to the score string
     *
     * @param email the email of the user
     */
    void addEmptyLine(String email);

    /**
     * Check if the email is in the database
     */
    boolean checkEmail(String email);

    /**
     * Check if the str in the database(hash)
     */
    boolean checkHash(String str);

    /**
     * Insert hash into database
     */
    boolean insertHash(String str);

}
