package com.example.educheckin.dataAccessObject;

import io.swagger.v3.oas.models.security.SecurityScheme;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

@Repository
public class ScoreDAOImpl implements ScoreDAO {
    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Override
    public String getSelfScoreDAO(String email) {
        String sql = "SELECT self_score_str FROM score WHERE email=?";
        return jdbcTemplate.queryForObject(sql, String.class, email);
    }

    @Override
    public String getGroupScoreDAO(String email) {
        String sql = "SELECT group_score_str FROM score WHERE email=?";
        return jdbcTemplate.queryForObject(sql, String.class, email);
    }

    @Override
    public String getStudentScoreDAO(String email) {
        String sql = "SELECT stu_score_str FROM score WHERE email=?";
        return jdbcTemplate.queryForObject(sql, String.class, email);
    }

    @Override
    public String getTeacherScoreDAO(String email) {
        String sql = "SELECT teacher_score_str FROM score WHERE email=?";
        return jdbcTemplate.queryForObject(sql, String.class, email);
    }

    @Override
    public boolean insertSelfScoreDAO(String email, String scoreString) {
        addEmptyLine(email);
        String sql = "UPDATE score SET self_score_str=? WHERE email=?";
        return jdbcTemplate.update(sql, scoreString, email) >= 1;
    }

    @Override
    public boolean insertGroupScoreDAO(String email, String scoreString) {
        addEmptyLine(email);
        //查看是否已经有小组评分
        String sql = "SELECT group_score_str FROM score WHERE email=?";
        String group_score_str = jdbcTemplate.queryForObject(sql, String.class, email);
        if (group_score_str.isEmpty()) {
            sql = "UPDATE score SET group_score_str=? WHERE email=?";
            return jdbcTemplate.update(sql, scoreString, email) >= 1;
        }
        sql = "UPDATE score SET group_score_str=? WHERE email=?";
        return jdbcTemplate.update(sql, getGroupScoreDAO(email) + " " + scoreString, email) >= 1;
    }

    @Override
    public boolean insertStudentScoreDAO(String email, String scoreString) {
        addEmptyLine(email);
        //查看是否已经有学生评分
        String sql = "SELECT stu_score_str FROM score WHERE email=?";
        String stu_score_str = jdbcTemplate.queryForObject(sql, String.class, email);
        if (stu_score_str.isEmpty()) {
            sql = "UPDATE score SET stu_score_str=? WHERE email=?";
            return jdbcTemplate.update(sql, scoreString, email) >= 1;
        }
        sql = "UPDATE score SET stu_score_str=? WHERE email=?";
        return jdbcTemplate.update(sql, getStudentScoreDAO(email) + " " + scoreString, email) >= 1;
    }

    @Override
    public boolean insertTeacherScoreDAO(String email, String scoreString) {
        addEmptyLine(email);
        //查看是否已经有老师评分
        String sql = "UPDATE score SET teacher_score_str=? WHERE email=?";
        return jdbcTemplate.update(sql, scoreString, email) >= 1;

    }

    @Override
    public void addEmptyLine(String email) {
        if (!checkEmail(email)) {
            String sql = "INSERT INTO score (email, self_score_str, stu_score_str, group_score_str, teacher_score_str)" +
                    " VALUES (?, ?, ? , ?,?)";
            jdbcTemplate.update(sql, email, "", "", "", "");
        }

    }

    @Override
    public boolean checkEmail(String email) {
        String sql = "SELECT * FROM score WHERE email=?";
        return jdbcTemplate.query(sql, (rs) -> {
            if (rs.next()) {
                return true;
            } else {
                return false;
            }
        }, email);
    }

    @Override
    public boolean checkHash(String str) {
        String sql = "SELECT * FROM hash WHERE hash=?";
        return Boolean.TRUE.equals(jdbcTemplate.query(sql, ResultSet::next, str));
    }

    @Override
    public boolean insertHash(String str) {
        String sql = "INSERT INTO hash (hash) VALUES (?)";
        return jdbcTemplate.update(sql, str) >= 1;
    }


}
