package com.example.educheckin.dataAccessObject;

import com.example.educheckin.entity.User;

import java.util.List;

public interface UserDAO
{
    /**
     * Check if the password is correct
     * @param email email of the user
     * @param password password of the user
     * @return true if correct, false if not
     */
    boolean checkPassword(String email, String password);

    /**
     * Register a new user, WARNING: this method does not check if the user is already in the database
     * @param user the user to be registered
     * @return true if the user is added, false if not
     */
    boolean addUser(User user);

    /**
     * Get all the emails in the database
     * @return a list of emails
     */
    List<String> getAllEmails();

    /**
     * Change the user information
     * @param email the email of the user to be changed
     * @param user the new user information
     * @return true if the user is changed, false if not
     */
    boolean change(String email, User user);

    /**
     * Get the user by email
     * @param email the email of the user
     * @return the user, null if the user is not found
     */
    User getUserByEmail(String email);

    /**
     * Get list of users which belong to the group, only students
     * @return the list of users
     */
    List<User> belongToGroup(String group);

    /**
     * Advise the user
     * @param advise
     * @return true if the success, false if not
     */
    public boolean advise(String advise);


}
