package com.example.educheckin.dataAccessObject;

import com.example.educheckin.entity.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.EmptyResultDataAccessException;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

@Repository
public class UserDAOImpl implements UserDAO
{
    @Autowired
    private JdbcTemplate jdbcTemplate;
    @Autowired
    private InviteCodeDAO inviteCodeDAO;

    @Override
    public boolean checkPassword(String email, String password) {
        String sql = "SELECT COUNT(*) FROM user WHERE email = ? AND password = ?";
        Object[] params = {email, password};
        try {
            int count = jdbcTemplate.queryForObject(sql, params, Integer.class);
            return count > 0; // 如果查询结果大于0，则说明用户名和密码匹配
        } catch (EmptyResultDataAccessException e) {
            return false; // 查询结果为空，用户名不存在或密码不匹配
        }
    }

    @Override
    public boolean addUser(User user)
    {
        String sql = "INSERT INTO user (email, password, name, gender, phone, internship, code, `group`,admin) VALUES (?, ?, ?, ?, ?, ?, ?, ? ,?)";
        return jdbcTemplate.update(sql, user.getEmail(), user.getPassword(), user.getName(), user.getGender(),
                                   user.getPhone(), user.getInternship(), user.getInviteCode(), user.GroupString(),
                                   user.getAdmin()) >= 1;
    }

    @Override
    public List<String> getAllEmails()
    {
        String sql = "SELECT email FROM user";
        return jdbcTemplate.queryForList(sql, String.class);
    }


    @Override
    public boolean change(String email, User user)
    {
        String sql = "UPDATE user SET email=?, password=?, name=?, gender=?, phone=?, internship=?, code=?, `group`=?,admin=? WHERE email=?";
        return jdbcTemplate.update(sql, user.getEmail(), user.getPassword(), user.getName(), user.getGender(),
                                   user.getPhone(), user.getInternship(), user.getInviteCode(), user.GroupString(),
                                   user.getAdmin(), email) >= 1;

    }


    @Override
    public User getUserByEmail(String email)
    {
        String sql = "SELECT * FROM user WHERE email=?";
        return jdbcTemplate.query(sql, (rs) -> {
            if (rs.next()) {
                return new User(
                        rs.getString("email"),
                        rs.getString("password"),
                        rs.getString("name"),
                        rs.getString("gender"),
                        rs.getString("phone"),
                        rs.getString("internship"),
                        rs.getString("code"),
                        rs.getString("group"),
                        rs.getString("admin")
                );
            } else {
                return null;
            }
        }, email);
    }

    @Override
    public List<User> belongToGroup(String group) {
        String sql = "SELECT * FROM user WHERE `group` LIKE ?";
        return jdbcTemplate.query(sql, (rs) -> {
            List<User> userList = new ArrayList<>();
            while (rs.next()) {
                if (!Objects.equals(rs.getString("admin"), "0")) {
                    continue;
                }
                User user = new User(
                        rs.getString("email"),
                        rs.getString("password"),
                        rs.getString("name"),
                        rs.getString("gender"),
                        rs.getString("phone"),
                        rs.getString("internship"),
                        rs.getString("code"),
                        rs.getString("group"),
                        rs.getString("admin")
                );
                userList.add(user);
            }
            return userList;
        }, group);
    }

    @Override
    public boolean advise(String advise) {
        String sql = "INSERT INTO advise (advise) VALUES ( ?)";
        return jdbcTemplate.update(sql,  advise) >= 1;
    }



}
