package com.example.educheckin.service;

import com.example.educheckin.entity.CheckInItem;

import java.sql.Timestamp;
import java.util.List;

public interface CheckService
{
    /**
     * Add an item to check table. ATTENTION: In the table, there is no timestamp at the same day for each user.
     * @param item the item to be added.
     * @return if added successfully, return "success", if there is an item at the same day, update the item and return "update", otherwise return "error".
     */
    String goCheck(CheckInItem item);

    /**
     * Get the item by email and timestamp at the same day.
     * @param email the email of the user.
     * @param time the time of the check.
     * @return the item, null if not found.
     */
    CheckInItem getCheck(String email, Timestamp time);

    /**
     * Get user's all check items.
     * @param email the email of the user.
     * @return the itemList, null if not found.
     */
    List<CheckInItem> getCheckList(String email);

    /**
     * Get the number of constant check before time(exclude that day).
     * @param email the email of the user.
     * @param time time the time of the check.
     * @return number of constant check before time.
     */
    int constantCheckNumber(String email, Timestamp time);

    /**
     * Get the number of all check status between time(include start day and end day).
     * @param email the email of the user.
     * @param start the start time.
     * @param end the end time.
     * @return a list of data , list[0] is total days, list[1] is total check days, list[2] is prepare days,
     *        list[3] is go class days, list[4] is listen class days, list[5] is mark homework days, list[6] is mark paper days.
     */
    List<Integer> calculateRateBetweenTime(String email, Timestamp start, Timestamp end);
}
