package com.example.educheckin.service;

import com.example.educheckin.dataAccessObject.CheckDAO;
import com.example.educheckin.entity.CheckInItem;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.util.Comparator;
import java.util.List;
@Service
public class CheckServicelmpl implements CheckService{
    @Autowired
    private CheckDAO checkDao;

    @Override
    public String goCheck(CheckInItem item)
    {
        int id = checkDao.getCheckIdDAO(item.getEmail(), item.getTime());
        if(id > 0)
        {
            checkDao.reviseCheckDAO(item, checkDao.getCheckIdDAO(item.getEmail(), item.getTime()));
            return "update";
        }
        else if(id == -1)
        {
            checkDao.addCheckDAO(item);
            return "success";
        }
        else return "error";
    }

    @Override
    public CheckInItem getCheck(String email, Timestamp time)
    {
        return checkDao.getCheckDAO(checkDao.getCheckIdDAO(email, time));
    }

    @Override
    public List<CheckInItem> getCheckList(String email)
    {
        return checkDao.getCheckListDAO(email);
    }

    @Override
    public int constantCheckNumber(String email, Timestamp time)
    {
        List<CheckInItem> result = checkDao.getCheckListDAO(email);
        //result 按照时间递减排序
        result.sort(Comparator.comparing(CheckInItem::getTime).reversed());
        int count = 0;
        ZonedDateTime zdt = time.toInstant().atZone(ZoneId.systemDefault()); // 转换为ZonedDateTime
        ZonedDateTime zdtStart = zdt.toLocalDate().atStartOfDay(zdt.getZone()); // 获取当天的第一秒
        ZonedDateTime zdtCheck = zdtStart.minusDays(1);
        boolean before = false;

        for(CheckInItem item : result)
        {
            if (item.getTime().before(Timestamp.from(zdtStart.toInstant())))
            {
                before = true;
            }
            ZonedDateTime current = item.getTime().toInstant().atZone(ZoneId.systemDefault()).toLocalDate().atStartOfDay(zdt.getZone());
            if (before && current.equals(zdtCheck))
            {
                count++;
                zdtCheck = zdtCheck.minusDays(1);
            }
            else if (!before)
            {
            }
            else
            {
                break;
            }
        }
        return count;
    }

    @Override
    public List<Integer> calculateRateBetweenTime(String email, Timestamp start, Timestamp end)
    {
        List<CheckInItem> result = checkDao.getCheckListDAO(email);
        //result 按照时间递减排序
        result.sort(Comparator.comparing(CheckInItem::getTime).reversed());
        int count = 0;
        ZonedDateTime zdt = start.toInstant().atZone(ZoneId.systemDefault()); // 转换为ZonedDateTime
        ZonedDateTime zdtStart = zdt.toLocalDate().atStartOfDay(zdt.getZone()); // 获取当天的第一秒

        ZonedDateTime zdtEnd = end.toInstant().atZone(ZoneId.systemDefault()); // 转换为ZonedDateTime
        zdtEnd = zdtEnd.toLocalDate().atStartOfDay(zdtEnd.getZone()).plusDays(1).minusNanos(1); // 获取当天的最后一秒

        int totalDays = (int) ((zdtEnd.toInstant().toEpochMilli() - zdtStart.toInstant().toEpochMilli()) / (1000 * 3600 * 24)) + 1;
        int checkDays = 0;
        int prepareDays = 0;
        int goClassDays = 0;
        int listenClassDays = 0;
        int markHomeworkDays = 0;
        int markPaperDays = 0;
        for (CheckInItem item : result)
        {
            if ((item.getTime().after(Timestamp.from(zdtStart.toInstant())) || item.getTime().equals(Timestamp.from(zdtStart.toInstant())))
                    && item.getTime().before(Timestamp.from(zdtEnd.toInstant())))
            {
                checkDays++;
                if (item.getPrepare() == 1)
                {
                    prepareDays++;
                }
                if (item.getGo_class() == 1)
                {
                    goClassDays++;
                }
                if (item.getListen_class() == 1)
                {
                    listenClassDays++;
                }
                if (item.getMark_homework() == 1)
                {
                    markHomeworkDays++;
                }
                if (item.getMark_paper() == 1)
                {
                    markPaperDays++;
                }
            }
        }

        return List.of(totalDays, checkDays, prepareDays, goClassDays, listenClassDays, markHomeworkDays, markPaperDays);


    }


}
