package com.example.educheckin.service;

import org.springframework.web.multipart.MultipartFile;

import java.io.InputStream;
import java.io.OutputStream;

public interface FileService
{
    /**
     * Upload/Update the evaluation form
     *
     * @param email                   the email of the user
     * @param selfAssessmentFormBin   the self-assessment form
     * @param mutualEvaluationFormBin the mutual-evaluation form
     * @param studentEvaluationForm   the student-evaluation form
     * @return the number of uploaded/updated forms, range from 0 to 3
     */
    int fileUpload(String email, MultipartFile selfAssessmentFormBin, MultipartFile mutualEvaluationFormBin,
                   MultipartFile studentEvaluationForm);

    /**
     * Get the self-assessment form
     *
     * @param email the email of the user
     * @return the self-assessment form
     */
    InputStream getSelfAssessmentForm(String email);

    /**
     * Get the mutual-evaluation form
     *
     * @param email the email of the user
     * @return the mutual-evaluation form
     */
    InputStream getMutualEvaluationForm(String email);

    /**
     * Get the student-evaluation form
     * @param email the email of the user
     * @return the student-evaluation form
     */
    InputStream getStudentEvaluationForm(String email);

    /**
     * Get the self-assessment form name
     *
     * @param email the email of the user
     * @return the self-assessment form name
     */
    String getSelfAssessmentFormName(String email);

    /**
     * Get the mutual-evaluation form name
     *
     * @param email the email of the user
     * @return the mutual-evaluation form name
     */
    String getMutualEvaluationFormName(String email);

    /**
     * Get the student-evaluation form name
     * @param email the email of the user
     * @return the student-evaluation form name
     */
    String getStudentEvaluationFormName(String email);

}