package com.example.educheckin.service;

import com.example.educheckin.entity.InviteCode;

import java.util.List;

public interface InviteCodeService
{
    /**
     * Add an inviteCode to database
     * @param inviteCode the inviteCode to be added
     * @return the status of adding.
     *        "success" if the code is added successfully.
     *        "code exist" if the code is already exist.
     *        "error" if the code is not added.
     */
    String addInviteCode(InviteCode inviteCode);

    /**
     * Set the code used
     * @param code the code to be set
     * @return the status of setting.
     *       "success" if the code is set successfully.
     *       "code not exist" if the code is not exist.
     *       "error" if the code is not set.
     *       "code used" if the code is already used.
     */
    String setCodeUsed(String code);

    /**
     * Update the inviteCode , WARNING this method only update the invite_code table.
     * @param inviteCode the inviteCode to be updated.
     * @return the status of updating. true if the code is updated successfully.
     *        false if the code is not updated.
     */
    boolean updateInviteCode(InviteCode inviteCode);

    /**
     * Get the inviteCode by code
     * @param code the code to be searched
     * @return the inviteCode, null if the code is not exist.
     */
    InviteCode getInviteCode(String code);

    /**
     * Summon a group of inviteCode based on the time
     * @return the list of inviteCode
     */
    public List<String> summonInviteCode();
}
