package com.example.educheckin.service;

import java.util.List;

public interface ScoreService {
    /**
     * Parse the score string to a list of score integers , use for self ,teacher and group
     * @param scoreString the score string
     *                    (1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F)
     *                    (the score string is separated by space)
     * @return the list of score integers
     */
    List<Integer> parseScoreString(String scoreString);

    /**
     * Parse the score string to a list of score integers , use for student
     * @param scoreString the score string
     *                    (1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F)
     *                    (the score string is separated by space)
     * @return the list of score integers
     */
    List<Integer> parseScoreString2(String scoreString);

    /**
     * Convert input into int list
     *
     * @param input the input string
     * @return the int list
     */
    public List<Integer> convertStringToList(String input);

    /**
     * Insert self score string into database(1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F)
     * @param email the email of the user
     * @param scoreString the score string of the user
     * @return true if the score is inserted, false if not
     */
    boolean insertSelfScore(String email, String scoreString);

    /**
     * Insert group score string into database(1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F),
     * here, if already have a group score, then append the new score to the end of the string, with space in between
     * @param email the email of the user
     * @param scoreString the score string of the user
     * @return true if the score is inserted, false if not
     */
    boolean insertGroupScore(String email, String scoreString);

    /**
     * Insert student score string into database(1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F),
     * here, if already have a student score, then append the new score to the end of the string, with space in between
     * @param email the email of the user
     * @param scoreString the score string of the user
     * @return true if the score is inserted, false if not
     */
    boolean insertStudentScore(String email, String scoreString);

    /**
     * Insert teacher score string into database(1 indicates A, 2 indicates B, 3 indicates C, 4 indicates D, 5 indicates F),
     * here, if already have a teacher score, then append the new score to the end of the string, with space in between
     * @param email the email of the user
     * @param scoreString the score string of the user
     * @return true if the score is inserted, false if not
     */
    boolean insertTeacherScore(String email, String scoreString);

    /**
     * Get self score by email
     * @param email the email of the user
     * @return the score of the user
     */
    List<Integer> getSelfScore(String email);

    /**
     * Get group score by email
     * @param email the email of the user
     * @return the score of the group
     */
    List<Integer> getGroupScore(String email);

    /**
     * Get student score by email
     * @param email the email of the user
     * @return the score of the student
     */
    List<Integer> getStudentScore(String email);

    /**
     * Get teacher score by email
     * @param email the email of the user
     * @return the score of the user
     */
    List<Integer> getTeacherScore(String email);

    /**
     * Check hash already exist
     * @param str the string to be checked
     * @return true if the email is already in the database, false if not
     */
    Boolean isRepeat(String str);
}
