package com.example.educheckin.service;

import com.example.educheckin.dataAccessObject.ScoreDAO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;

@Service
public class ScoreServiceImpl implements ScoreService {
    @Autowired
    private ScoreDAO scoreDAO;

    @Override
    public List<Integer> parseScoreString(String scoreString) {
        if(Objects.equals(scoreString, "") || scoreString.isEmpty()) {
            return Arrays.asList(0, 0, 0, 0, 0, 0, 0, 0);
        }
        String[] scoreStringArray = scoreString.split(" ");
        List<Integer> totalScore = Arrays.asList(0, 0, 0, 0, 0, 0, 0, 0);
        for (String s : scoreStringArray) {
            //将字符串转换为列表
            List<Integer> score = new ArrayList<>();
            List<Integer> integerList = convertStringToList(s);
            for (int i : integerList) {
                switch (i) {
                    case 1:
                        score.add(100);
                        break;
                    case 2:
                        score.add(90);
                        break;
                    case 3:
                        score.add(80);
                        break;
                    case 4:
                        score.add(60);
                        break;
                    case 5:
                    default:
                        score.add(0);
                        break;
                }
            }
            int[] indices = {0, 2, 4, 6, 7, 9, 13, 16}; // 每个类别的起始索引
            int[] divisors = {2, 2, 2, 1, 2, 4, 3, 3}; // 每个类别的除数

            for (int i = 0; i < indices.length; i++) {
                int startIndex = indices[i];
                int endIndex = i < indices.length - 1 ? indices[i + 1] : score.size();
                int sum = 0;

                for (int j = startIndex; j < endIndex; j++) {
                    sum += score.get(j);
                }

                totalScore.set(i, totalScore.get(i) + sum / divisors[i]);
            }

        }
        //将totalScore除以总评价数
        totalScore.replaceAll(integer -> integer / scoreStringArray.length);
        return totalScore;
    }

    @Override
    public List<Integer> parseScoreString2(String scoreString) {
        if (Objects.equals(scoreString, "") || scoreString.isEmpty()) {
            return Arrays.asList(0, 0, 0, 0, 0);
        }
        String[] scoreStringArray = scoreString.split(" ");
        List<Integer> totalScore = Arrays.asList(0, 0, 0, 0, 0);
        for (String s : scoreStringArray) {
            //将字符串转换为列表
            List<Integer> score = new ArrayList<>();
            List<Integer> integerList = convertStringToList(s);
            for (int i : integerList) {
                switch (i) {
                    case 1:
                        score.add(100);
                        break;
                    case 2:
                        score.add(90);
                        break;
                    case 3:
                        score.add(80);
                        break;
                    case 4:
                        score.add(60);
                        break;
                    case 5:
                    default:
                        score.add(0);
                        break;
                }
            }
            int[] indices = {0, 3, 6, 9, 13}; // 每个类别的起始索引
            int[] divisors = {3, 3, 3, 4, 2}; // 每个类别的除数

            for (int i = 0; i < indices.length; i++) {
                int startIndex = indices[i];
                int endIndex = i < indices.length - 1 ? indices[i + 1] : score.size();
                int sum = 0;

                for (int j = startIndex; j < endIndex; j++) {
                    sum += score.get(j);
                }

                totalScore.set(i, totalScore.get(i) + sum / divisors[i]);
            }

        }
        //将totalScore除以总评价数
        totalScore.replaceAll(integer -> integer / scoreStringArray.length);
        return totalScore;
    }

    @Override
    public List<Integer> convertStringToList(String input) {
        List<Integer> result = new ArrayList<>();

        for (int i = 0; i < input.length(); i++) {
            char c = input.charAt(i);
            if (Character.isDigit(c)) {
                int digit = Character.getNumericValue(c);
                result.add(digit);
            }
        }
        return result;
    }

    @Override
    public boolean insertSelfScore(String email, String scoreString) {
        return scoreDAO.insertSelfScoreDAO(email, scoreString);
    }

    @Override
    public boolean insertGroupScore(String email, String scoreString) {
        return scoreDAO.insertGroupScoreDAO(email, scoreString);
    }

    @Override
    public boolean insertStudentScore(String email, String scoreString) {
        return scoreDAO.insertStudentScoreDAO(email, scoreString);
    }

    @Override
    public boolean insertTeacherScore(String email, String scoreString) {
        return scoreDAO.insertTeacherScoreDAO(email, scoreString);
    }

    @Override
    public List<Integer> getSelfScore(String email) {
        return parseScoreString(scoreDAO.getSelfScoreDAO(email));
    }

    @Override
    public List<Integer> getGroupScore(String email) {
        return parseScoreString(scoreDAO.getGroupScoreDAO(email));
    }

    @Override
    public List<Integer> getStudentScore(String email) {
        return parseScoreString2(scoreDAO.getStudentScoreDAO(email));
    }

    @Override
    public List<Integer> getTeacherScore(String email) {
        return parseScoreString(scoreDAO.getTeacherScoreDAO(email));
    }

    @Override
    public Boolean isRepeat(String str) {
        //use SHA1 Secure Hash Algorithm 1
        String sha = org.apache.commons.codec.digest.DigestUtils.sha512_224Hex(str);
        if (!scoreDAO.checkHash(sha)) {
            scoreDAO.insertHash(sha);
            return true;
        } else {
            return false;
        }
    }

}
