package com.example.educheckin.service;

import com.example.educheckin.entity.User;

import java.util.List;

public interface UserService
{
    /**
     * Register a new user
     * @param user the user to be registered
     * @return the status of registering.
     *       "success" if the user is registered successfully.
     *       "email exist" if the email is already exist.
     *       "code not exist" if the invite code is not exist.
     *       "code used" if the invite code is already used.
     *       "error" if the user is not registered.
     */
    String register(User user);

    /**
     * Login with email and password
     * @param email the email to be logged in
     * @param password the password to be logged in
     * @return the status of logging in.
     *      true if the user is logged in successfully.
     *      false if the user is not logged in.
     */
    boolean login(String email, String password);

    /**
     * Get the user by email
     * @param email the email to be searched
     * @return the status of changing.
     *     "success" if the user is changed successfully.
     *     "email not exist" if the email is not exist.
     *     "email exist" if the email is already exist.
     *     "error" if the user is not changed.
     */
    String changeInfo(String email, User user);

    /**
     * Get the user by email
     * @param email the email to be searched
     * @return the user, null if the email is not exist.
     */
    User getUser(String email);

    /**
     * Get list of users which belong to the group, only students
     * @return the list of users
     */
    List<User> belongToGroup(String group);

    /**
     * Advise the user
     * @param advise
     * @return true if the success, false if not
     */
    public boolean advise(String advise);

}
